#!/usr/bin/python3
#myservice_description: global notificator/in development
#
#   I need to combine with the advanced RPIHAT (running invisibly in screen)
#
#
import notify2
#sudo aptitude install python3-notify2
import time
#from multiprocessing import Queue
from queue import LifoQueue, Queue, Empty, Full
import os
import glob
import subprocess
from fire import Fire
from gtts import gTTS
#from pydub import AudioSegment
#from pydub.playback import play
from playsound import playsound
#from pydub.utils import make_chunks
import re
from notifator import notihat
from notifator import hodiny
from notifator import ntfy
from unidecode import unidecode

import select
import sys
import requests # ntfy.sh


import datetime as dt
import json
import os

#
# detect pipe mode... taken from cmdai
#


def is_cron():
    return not os.isatty(sys.stdin.fileno())

def pipe_mode():
    """
    detect mode - pipe or not
    """
    if is_cron():
        return None
    if select.select([sys.stdin, ], [], [], 0.0)[0]:
        print(f"D... {fg.lightslategray}Pipe mode detected! {fg.default}")
        mstdin = []
        for line in sys.stdin:
            mstdin.append( line.strip() )
        return mstdin
    # UNCLESS IT IS NOT
    else:
        # print(f"D... {fg.lightgray} NO Pipe  {fg.default}")
        return None #print("No pipe")


def take_time():
    return str(dt.datetime.now())[:-7]



class ScreenTool:
    servlist=[]
    def __init__(self):
        res=self.check_myservice()
        print("i... "+str(len(res))+" screens seen for the user")
        print( "i... : {}\n".format(res ) )


    def check_myservice(self):
        #### CMD="screen -ls "+self.screenname
        user_name = os.getenv('USER')
        res=glob.glob( "/var/run/screen/S-"+user_name+"/*" )
        res=[os.path.basename(x) for x in res] # 4321.myservice_
        shortres=["".join(x.split(".")[1:]) for x in res]
        self.servlist=res
        return res


    def run_screen(self, name, cmd):
        self.screenname=name
        print("i... starting screen")
        CMD=cmd
        print("D...  --- ",CMD)
        CMD='/usr/bin/screen -dmS '+self.screenname+' bash -c  "'+CMD+'"'
        print( CMD )
        ok=False
        #try:
        subprocess.check_call( CMD, shell=True )
        ok=True
        print("i...      run ok ")
        print("i...  screen STARTED")
        #except:
        #print("X...      xxx... screen  PROBLEM")


# ********************************************************
# ********************************************************
# ********************************************************
# ********************************************************
#
#
#  This is the main object.... housing   audio,hat,term,dbus....
#
# then later - the message is queued:
#    q.put( NotifyClass('audio',msg) )
#
#
# ********************************************************
# ********************************************************
# ********************************************************

class NotifyClass(object):

    def __init__(self, dest, message, timeshow = 10, color = 1.1):
        print("D... notifator target/message:",dest,"/",message)
        self.dest = dest
        self.message = message
        self.timeshow = timeshow
        self.color = color
        self.mp3 = None

        if self.message is not None:
            if os.path.exists(self.message):
                print(f"D... file exists {self.message}")
                print("D...  checking mp3 extension",os.path.splitext(self.message)[1])
                if os.path.splitext(self.message)[1]==".mp3":
                    self.mp3 = self.message
        else:
            print("D.... maybe clock ??")


    # **********************************************************************
    # **********************************************************************

    def audio(self, lang="cs", CACHE="~/sound_cache/", playme = True):
        """
Use google etxt to speech, not too frequently. Creates an mp3 in /tmp and reads it
        """
        if self.mp3 is not None:
            playsound(self.mp3)
            return

        cache = os.path.expanduser(CACHE)
        #print("@"+self.audio.__name__, end='')
        #t = re.compile("[a-zA-Z0-9.,_-]")

        #CMD = f"iconv -f utf-8 -t ascii//TRANSLIT"
        #sp.check_call( CMD )

        t = re.compile("[a-zA-Z0-9_]+") # safe characters
        #unsafe = "abc∂éåß®∆˚˙©¬ñ√ƒµ©∆∫ø"
        unsafe=self.message

        #unidecode(u"Žluťoučký kůň")
        safe = unidecode(unsafe)
        print("D... ",safe)
        safe = safe.replace(" ","_")
        print("D... ",safe)
        #
        safe = [ch for ch in safe if t.match(ch)]
        print("D... ",safe)
        safe = "".join(safe)
        print("D... ",safe)

        outfile="/tmp/msg_"+safe+".mp3"
        if os.path.exists(cache):
            outfile = f"{cache}/{safe}.mp3"
            outfile = outfile.replace("//","/")

        if not os.path.isfile(outfile):
            print("D... contacting google for tts ...", self.message)
            tts=gTTS( self.message+"." , lang=lang)
            tts.save(outfile)
        else:
            print(f"D... taking sound from {outfile}")

        # read it
        #path_to_file = outfile
        #song = AudioSegment.from_mp3(path_to_file)
        #play(song) # it was  +8 which may be volume up
        if playme:
            playsound(outfile)
        return outfile #self.message


    # **********************************************************************
    # **********************************************************************


    def multicast(self):

        outfile = ""
        if self.mp3 is not None:
            outfile = self.mp3
        else:
            outfile = self.audio( playme = False)
        #CMD = f"ffmpeg -re  -i {outfile}  -acodec libopus -b:a 12k -f rtp rtp://239.0.0.1:8786"
        CMD = f"ffmpeg -re -fflags nobuffer -i {outfile}  -acodec libopus -b:a 72k -f mpegts udp://239.0.0.1:8786"
        # receive with # mpv --cache=no  --framedrop=no --speed=1.01  udp://239.0.0.1:8786
        CMD = f"ffmpeg -re -fflags nobuffer -flags low_delay  -strict experimental -i {outfile} -acodec libopus -b:a 196k -f mpegts 'udp://239.0.0.1:8786?pkt_size=128'"
        # ----this seems to work !!! no flasgc
        CMD = f"ffmpeg -re   -fflags nobuffer  -i {outfile} -acodec libopus -b:a 32k -f mpegts 'udp://239.0.0.1:8786?pkt_size=512'"
        print(CMD)
        print(CMD)
        subprocess.check_call( CMD, shell=True )


    # **********************************************************************
    # **********************************************************************

    def multicast_clock(self):
        """
        New
        """
        print("D....    multicast clock,.....")
        mp3file = hodiny.hodiny()
        print("D....    multicast clockdone,.....")
        self.mp3 = mp3file
        #outfile =
        if self.mp3 is not None:
            outfile = self.mp3
        else:
            outfile = self.audio( playme = False)
        #CMD = f"ffmpeg -re  -i {outfile}  -acodec libopus -b:a 12k -f rtp rtp://239.0.0.1:8786"
        self.multicast()


    # **********************************************************************
    # **********************************************************************

    def dbus(self):
        #print("@"+self.dbus.__name__+' ', end='')
        notify2.init("--Title--")
        #notice = notify2.Notification(self.dest, self.message)
        notice = notify2.Notification( self.message )
        notice.show()
        time.sleep(0.1)
        return self.message

    # **********************************************************************
    # **********************************************************************

    def hat(self):
        #print("@"+self.hat.__name__+'  ', end='')
        print("D... HAT ON")
        notihat.main(message=self.message,
                     timeshow=self.timeshow,
                     color = self.color)
        return self.message


    def web(self):
        """
        I dont remember what this was
        """
        #print("@"+self.web.__name__+'  ', end='')
        return self.message

    # **********************************************************************
    # **********************************************************************

    def ntfy_sh(self, scrshot=False):
        """
        Let all heavy lifting to ntfy.py, just define the message and title
        """
        now = take_time()
        title = f"{now}"
        message = self.message
        filename = None
        ntfy.send_ntf(message, title, scrshot=scrshot)

        # if scrshot:
        #     message = f""#THE message {now}"
        #     title = self.message # the message will be in the title
        #     filename = take_screenshot(w=200)
        #     data=open(filename, 'rb')
        #     filename = "m.jpg"
        # else:
        #     data = self.message
        #     title = ""
        #     # no message here for some reason... and title = "" to make it short

        #     # "Actions": "http, OpenSeznam, https://www.seznam.cz/, method=PUT, headers.Authorization=Bearer zAzsx1sk.., body={\"action\": \"close\"}"   }
        # response = requests.put( url_full,
        #                          data=data,
        #                          headers={ "Title": f"{title}",
        #                                    "Filename": filename,
        #                                    "message": message,
        #                                   # "Actions": "http, OpenSeznam, https://www.seznam.cz/ "
        #                                   }
        #                         )

        # if response.status_code == 200:
        #     print("Notification with image sent successfully! ntfy.sh")
        # else:
        #     print("Failed to send notification.  ntfy.sh")
        # return self.message

    # **********************************************************************
    # **********************************************************************
    def ntfy_sh_scr(self, scrshot=True):
        """
        just call with rue parameter .... ./bin_notifator.py n hoj 1
        """
        self.ntfy_sh(scrshot=True)
        return self.message

    # **********************************************************************
    # **********************************************************************
    def term(self):
        """
        add the user to tty group to be able to listen
        usermod -a -G tty  user
        """

        #print("@"+self.term.__name__+' ', end='')
        msg=self.message
        print(msg)
        msg=msg.replace('"',' ')
        msg=msg.replace('\\',' ')
        msg=msg.replace('|',' ')
        msg=msg.replace('$',' ')
        msg=msg.replace('#',' ')
        msg=msg.replace('`',' ')
        msg=msg.replace("'",' ')
        os.system('echo "'+msg+'" | wall')
        return self.message

#============ this RUNS the message on destination. Call do
#
#
#

    def do( self ):
        return getattr(NotifyClass, self.dest)(self)


#===================================================================
#
#===================================================================
#
#
#
#

def issueall(message):
    """Issues message to all: audio, dbus, hat, term
    """
    q = Queue(6)   # how does this work?

    msg = message
    pmo = pipe_mode()# from pipe
    if pmo is not None:
        msg = '\n'.join(pmo)

    q.put( NotifyClass('audio',msg) )
    #q.put( NotifyClass('dbus' ,'notify-send way - works with gtk') )
    q.put( NotifyClass('dbus' ,   msg  ) )
    q.put( NotifyClass('hat'  , 'Init sense hat and display') )
    #q.put( NotifyClass('web'  , 'connect to webpy.py') )
    q.put( NotifyClass('term' , msg) )

    #================== RPIHAT PART
    #s=ScreenTool()
    #s.run_screen("sleeptest","sleep 10") # this can contain rpihat...

    while not q.empty():
        res=q.get().do()
        #print("   ", res)


#===================================================================
#
#===================================================================
#
#
#
#

def issue_hat(message = None, timeshow = 13, color = 1.1):
    """ Issues a message to RpiHAT (or the emulator)
    """
    print("D... issue_hat")
    q = Queue(6)
    print(q)


    msg = message
    pmo = pipe_mode()# from pipe
    if pmo is not None:
        msg = '\n'.join(pmo)


    q.put( NotifyClass('hat', msg, timeshow , color) )
    print("D... hat in queue")
    while not q.empty():
        res=q.get().do()


#===================================================================
#
#===================================================================
#
#
#
#

def issue_sound(message = None):
    """Issues a message to speech translator and plays locally
    """
    q = Queue(6)   # how does this work?


    msg = message
    pmo = pipe_mode()
    if pmo is not None:
        msg = '\n'.join(pmo)
    q.put( NotifyClass('audio',msg) )
    #q.put( NotifyClass('dbus' ,'notify-send way - works with gtk') )
    #q.put( NotifyClass('dbus' ,   message  ) )
    #q.put( NotifyClass('hat'  , 'Init sense hat and display') )
    #q.put( NotifyClass('web'  , 'connect to webpy.py') )
    #q.put( NotifyClass('term' , message) )

    while not q.empty():
        res=q.get().do()
#===================================================================
#
#===================================================================
#
#
#
#

def issue_term(message = None):
    """Issues a message on term wall /untested/
    """
    q = Queue(6)   # how does this work?

    msg = message
    pmo = pipe_mode() # from pipe
    if pmo is not None:
        msg = '\n'.join(pmo)
    q.put( NotifyClass('term',msg) )
    #q.put( NotifyClass('dbus' ,'notify-send way - works with gtk') )
    #q.put( NotifyClass('dbus' ,   message  ) )
    #q.put( NotifyClass('hat'  , 'Init sense hat and display') )
    #q.put( NotifyClass('web'  , 'connect to webpy.py') )
    #q.put( NotifyClass('term' , message) )

    while not q.empty():
        res=q.get().do()


#===================================================================
#
#===================================================================
#
#
#
#

def issue_multicast(message = None):
    """Issues a message to speech translator and multicasts on port 8786
    """
    q = Queue(6)   # how does this work?

    msg = message
    pmo = pipe_mode()# from pipe
    if pmo is not None:
        msg = '\n'.join(pmo)


    q.put( NotifyClass('multicast',msg) )
    #q.put( NotifyClass('dbus' ,'notify-send way - works with gtk') )
    #q.put( NotifyClass('dbus' ,   message  ) )
    #q.put( NotifyClass('hat'  , 'Init sense hat and display') )
    #q.put( NotifyClass('web'  , 'connect to webpy.py') )
    #q.put( NotifyClass('term' , message) )

    while not q.empty():
        res=q.get().do()


#===================================================================
#
#===================================================================
#
#
#
#

def issue_multicast_clock(message = None):
    """Issues a message to speech translator and multicasts on port 8786
    """
    q = Queue(6)   # how does this work?

    msg = message
    pmo = pipe_mode()# from pipe
    if pmo is not None:
        msg = '\n'.join(pmo)

    print("D... qput")
    q.put( NotifyClass('multicast_clock', message) )
    print("D... *DONE*")
    #q.put( NotifyClass('dbus' ,'notify-send way - works with gtk') )
    #q.put( NotifyClass('dbus' ,   message  ) )
    #q.put( NotifyClass('hat'  , 'Init sense hat and display') )
    #q.put( NotifyClass('web'  , 'connect to webpy.py') )
    #q.put( NotifyClass('term' , message) )

    while not q.empty():
        res=q.get().do()

#===================================================================
#
#===================================================================
#

def issue_dbus(message = None):
    """Issues a message to DBUS system (crash on RPi)
    """
    q = Queue(6)   # how does this work?

    msg = message
    pmo = pipe_mode()# from pipe
    if pmo is not None:
        msg = '\n'.join(pmo)

    #q.put( NotifyClass('audio',message) )
    #q.put( NotifyClass('dbus' ,'notify-send way - works with gtk') )
    q.put( NotifyClass('dbus' ,   msg  ) )
    #q.put( NotifyClass('hat'  , 'Init sense hat and display') )
    #q.put( NotifyClass('web'  , 'connect to webpy.py') )
    #q.put( NotifyClass('term' , message) )

    while not q.empty():
        res=q.get().do()

#===================================================================
#
#===================================================================
#

def issue_ntfy_sh(message , scrshot=False):
    """Issues a message ntfy.sh
    """
    if scrshot:
        print("D... screenshot required... ntfy.sh")
    q = Queue(6)   # how does this work?

    msg = message
    pmo = pipe_mode()# from pipe
    if pmo is not None:
        msg = '\n'.join(pmo)

    if scrshot:
        q.put( NotifyClass('ntfy_sh_scr' ,   msg    ) )
    else:
        q.put( NotifyClass('ntfy_sh' ,   msg    ) )

    while not q.empty():
        res=q.get().do()


#============================================================
#============================================================
#============================================================
#============================================================
#============================================================

if __name__=="__main__":
    Fire( {"a":issueall,
           "s":issue_sound,
           "m":issue_multicast,
           "c":issue_multicast_clock,
           "n":issue_ntfy_sh,
           "t":issue_term,
           "h":issue_hat,
           "b":issue_dbus}
         )



#!/usr/bin/env python3
"""
A simple telegram bot -  use as "say ahoj".
Commands /saytime /bustime /who ...
can be defined via /setcommands in @Fatherbot -
- see /help
"""

from telegram.ext import Updater, CommandHandler, MessageHandler, Filters
import os
from configparser import ConfigParser

from fire import Fire

import socket

from notifator import notify
import datetime

def load_config( mysection ):
    configur = ConfigParser()
    tokenpath = "~/.telegram.token"
    ok  = False
    try:
        print(os.path.expanduser(tokenpath))
        configur.read(os.path.expanduser(tokenpath) )
        ok = True
    except:
        print("X... cannot read the config from file ",tokenpath)
    if not ok:
        quit()

    sections=configur.sections()
    if mysection in sections:
        token = configur.get( mysection, "token")
        chatid = configur.get( mysection, "chatid")
        return token, chatid
    else:
        print("X... section not found: ", mysection)
        print("X... possible sections:", sections)
        quit()



# Define a few command handlers. These usually take the two arguments update and
# context. Error handlers also receive the raised TelegramError object in error.
def start(update, context):
    """Send a message when the command /start is issued."""
    myname=socket.gethostname()
    print("D... starting, myname", myname)
    update.message.reply_text('Hi, '+myname +" ready!")


def help_command(update, context):
    """Send a message when the command /help is issued."""
    hlp = """ Define these commands in @Fatherbot via /setcommand :
saytime - say time
bustime - dbus time show
who - who is listenning
say_hello - say it
bus_hello - dbus message
    """
    update.message.reply_text('help_command launched \n\n'+hlp)


def say(update, argument):
    myname=socket.gethostname()
    print("D... argument", argument)
    notify.issue_sound(argument)
    update.message.reply_text("from:"+myname+" ... I tried to read it")


def bus(update, argument):
    myname=socket.gethostname()
    print("D... argument", argument)
    notify.issue_dbus(argument)
    update.message.reply_text("from:"+myname+" ... I tried to display it on dbus")



def say_command(update, context):
    """Send a message when the command /say is issued."""
    #update.message.reply_text('say_command  launched '+update.message.text)
    say(update,"halo!")

def saytime_command(update, context):
    """Send a message when the command /say is issued."""
    #update.message.reply_text('say_command  launched '+update.message.text)
    hour = datetime.datetime.now().strftime("%H:%M")
    say(update, hour )


def bus_command(update, context):
    """Send a message when the command /bus is issued."""
    #update.message.reply_text('bus_command  launched '+update.message.text)
    bus(update,"halo!")

def bustime_command(update, context):
    """Send a message when the command /bus is issued."""
    #update.message.reply_text('bus_command  launched '+update.message.text)
    hour = datetime.datetime.now().strftime("%H:%M")
    bus(update,hour)


def who_command(update, context):
    """Send a message when the command /who is issued."""
    #update.message.reply_text('who_command  launched '+update.message.text)
    myname=socket.gethostname()
    #print("D... argument", argument)
    update.message.reply_text(myname+": is ready")


def echo(update, context):
    """Echo the user message."""
    pic=os.path.expanduser('~/Figure_1.png')
    # PIC HERE
    # context.bot.send_photo(chat_id=update.effective_chat.id, photo=open(pic,'rb'))
    ###context.message.sendPhoto(photo="url_of_image",
    ###                      caption="This is the test photo caption")

    mmm = update.message.text
    print("D... message",mmm, mmm.lower().find("say "))
    if mmm.lower().find("say ")==0:
        argument = mmm[4:]
        say(update, argument)
    elif mmm.lower().find("bus ")==0:
        argument = mmm[4:]
        bus(update,argument)
    else:
        myname=socket.gethostname()
        update.message.reply_text("echo from:"+myname+": "+mmm)


def main(section):
    """Start the bot."""
    # Create the Updater and pass it your bot's token.
    # Make sure to set use_context=True to use the new context based callbacks
    # Post version 12 this will no longer be necessary

    token,chatid=load_config(section)
    updater = Updater(token,
                      use_context=True)

    # Get the dispatcher to register handlers
    dp = updater.dispatcher

    # on different commands - answer in Telegram
    dp.add_handler(CommandHandler("start", start))
    dp.add_handler(CommandHandler("help", help_command))
    dp.add_handler(CommandHandler("say_hello", say_command))
    dp.add_handler(CommandHandler("saytime", saytime_command))
    dp.add_handler(CommandHandler("bus_hello", bus_command))
    dp.add_handler(CommandHandler("bustime", bustime_command))
    dp.add_handler(CommandHandler("who", who_command))

    # on noncommand i.e message - echo the message on Telegram
    dp.add_handler(MessageHandler(Filters.text & ~Filters.command, echo))

    # Start the Bot
    updater.start_polling()

    # Run the bot until you press Ctrl-C or the process receives SIGINT,
    # SIGTERM or SIGABRT. This should be used most of the time, since
    # start_polling() is non-blocking and will stop the bot gracefully.
    updater.idle()


if __name__ == '__main__':
    Fire( main )



#!/usr/bin/env python3

from fire import Fire
import datetime as dt
from notifator.version import __version__

import cv2
import requests
import os
import sys
#----------------- text config file --------
from configparser import ConfigParser
# for take_image
import subprocess as sp
from PIL import Image




def load_config( mysection, cfile="~/.notifator.rc" ):
    configur = ConfigParser()
    address = None
    ok  = False
    try:
        #print("D... config path",os.path.expanduser(cfile))
        configur.read(os.path.expanduser(cfile) )
        ok = True
    except:
        print("X... cannot read the config from file ",cfile)
    if not ok:
        sys.exit(1)

    sections=configur.sections()
    if mysection in sections:
        address = configur.get(mysection, "address")
        return address
    else:
        print("X... section not found: ", mysection)
        print("X... possible sections:", sections)
        sys.exit(0)


def take_screenshot( w=320, h=None):
    """
    gnome-screenshot
    """
    # Take the screenshot
    file_size = None
    sp.run(['gnome-screenshot', '-f', '/tmp/screenshot.png'])
    filename = None
    # Open the screenshot, resize, and save as JPG
    with Image.open('/tmp/screenshot.png') as img:
        original_width, original_height = img.size
        aspect_ratio = original_height / original_width
        h = int(w * aspect_ratio)
        img = img.convert('RGB')
        img = img.resize((w, h))
        filename=f'/tmp/screenshot_{w}_{h}.jpg'
        img.save(filename, 'JPEG')
        file_size = os.path.getsize(filename)
        print(f"i... file size = {file_size}")
    return filename



def send_ntf(message, title, section="default", scrshot=False):
    """
    send to ntfy.sh
    """

    url_full = load_config( section )
    #now = take_time()
    #title = f"{now}"
    #message = message
    #filename = None

    data = None
    filename = None
    msg2 = message
    tit2 = title

    if scrshot:
        msg2 = f""#THE message {now}"
        tit2 = message # the message will be in the title
        filename = take_screenshot(w=200)
        data=open(filename, 'rb')
        filename = filename
    else:
        data = message
        tit2 = ""
        # no message here for some reason... and title = "" to make it short
        # "Actions": "http, OpenSeznam, https://www.seznam.cz/, method=PUT, headers.Authorization=Bearer zAzsx1sk.., body={\"action\": \"close\"}"   }
    response = requests.put( url_full,
                             data=data,
                             headers={ "Title": f"{tit2}",
                                       "Filename": filename,
                                       "message": msg2,
                                       # "Actions": "http, OpenSeznam, https://www.seznam.cz/ "
                                      }
                            )

    if response.status_code == 200:
        print("Notification with image sent successfully! ntfy.sh")
    else:
        print("Failed to send notification.  ntfy.sh")
    return #message




def main():
    ad = load_config( "default" )
    print(f"i... sending to {ad}")
    send_ntf(f"test {dt.datetime.now()}", "tItLe", scrshot=False)

if __name__ == "__main__":
    Fire(main)



#!/usr/bin/env python3
# -fire CLI
from fire import Fire
from notifator.version import __version__

import cv2
import requests
import os
import sys

#----------------- text config file --------
from configparser import ConfigParser

import numpy as np
import datetime as dt

import re  # escape markdown


"""
Practical:
 - In botfather do /newbot
 - NAME
 - NAMEbot
 - Click the bot link in telegram and start it (big button is ok)
 - https://api.telegram.org/bot123456789:AA..4Q/getUpdates
 - if started, it shows info... also "chat":{"id":133760184,...
 - but, all my chats have the same id....
 - the link to it seems to be t.me/NAMEbot
------------------------------------------

The trick:  In Botfather, create /newbot,
 - select a name Btrfs
 - select a username Btrfsbot

- start the bot in telegram - in @Father /mybots,
  click @Brtfsbot, press start or /start

1- remember the API key
from API on web
https://api.telegram.org/bot123456789:AA..4Q/getUpdates
- already after start it should give chatid
- chatid seems be the same for all

LEVEL2:
==================================================
pip3 install python-telegram-bot


OLD:
==================================================
- start the bot in telegram - /mybots...
- possibly send some text from phone...
/start
neco
/getUpdates
https://api.telegram.org/bot123456789:AA..J4Q/getMe
-
2- remember the chat_id
3- put APIkey and chat_id to ~/.telegram.token
...
markdown doesnt work with multiline
YES, just give double \n\n
"""


# print("i... module notifator/telegram is being run")

def func():
    print("D... function defined in notifator:telegram")
    return True

def test_func():
    print("D... test function ... run pytest")
    assert func()==True




def load_config( mysection ):
    configur = ConfigParser()
    tokenpath = "~/.telegram.token"
    ok  = False
    try:
        print("D... confing path",os.path.expanduser(tokenpath))
        configur.read(os.path.expanduser(tokenpath) )
        ok = True
    except:
        print("X... cannot read the config from file ",tokenpath)
    if not ok:
        sys.exit(0)

    sections=configur.sections()
    if mysection in sections:
        token = configur.get( mysection, "token")
        chatid = configur.get( mysection, "chatid")
        return token, chatid
    else:
        print("X... section not found: ", mysection)
        print("X... possible sections:", sections)
        sys.exit(0)



# def get_token():
#     tokenpath="~/.telegram.token"
#     try:
#         with open( os.path.expanduser(tokenpath) ) as f:
#             res=f.readlines()
#     except:
#         print("X... cannot read",tokenpath)
#         quit()
#     res=[ x.strip() for x in res]
#     token,chat_id=res
#     print( token, chat_id)
#     return token, chat_id


def bot_send(section, bot_message, bot_photo="" , parsemode = "markdown"):
    """
    Telegram send. Parameters: Bot (Btrfs), Message (Blabla)
   parsemode markdown makes lot of problems
    """
    if bot_message=="":
        print("X... zero message")
        quit()
#    bot_token, bot_chatID= get_token()
    bot_token, bot_chatID= load_config(section)
    #    bot_token = ''
    #    bot_chatID = ''



    #bot_message = re.escape( bot_message )
# '_', '*', '[', ']', '(', ')', '~', '`', '>', '#', '+', '-', '=', '|', '{', '}', '.', '!'


    ### filename = ""
    print("_______________ *bot_hoto* _______________")
    print( type(bot_photo)  )
    if (type(bot_photo)==np.ndarray):
        filename = f"/tmp/flashcam_{dt.datetime.now().strftime('%Y%m%d_%H%M%S')}.jpg"
        print(f"i... (tele:) writing ndarr image {filename}")
        cv2.imwrite(filename, bot_photo)
        bot_photo = filename

    if (bot_photo==""): #======= NO PHOTO =============
        url='https://api.telegram.org/bot' + bot_token + '/sendMessage'
        payload = {'chat_id':bot_chatID,
#                   "parse_mode": parsemode,  # "markdown"
                   'text':bot_message}
#        send_text = 'https://api.telegram.org/bot' + bot_token + '/sendMessage?chat_id=' + bot_chatID + '&parse_mode=MarkdownV2&text=' + bot_message

        print("i... ",url)
        print("i... ",payload)
        requests.packages.urllib3.disable_warnings()
        response = requests.post(url,  data=payload, verify=False)
        #response = requests.get(send_text)


    else: #====================YES PHOTO================
        if not os.path.isfile(bot_photo):
            print("X... cannot find picture", bot_photo)
            quit()

        files = {'photo': open(bot_photo, 'rb')}
        payload = {'chat_id':bot_chatID,
#                   "parse_mode": "markdown",
                   'caption':bot_message}
        url='https://api.telegram.org/bot' + bot_token + '/sendPhoto'
        print("i... ",url)
        print("i... ",payload)
        response = requests.post(url, files=files, data=payload, verify=False)
        # print( response )
    #----------------------
    print("D... returning response")
    return response.json()














if __name__=="__main__":
#    print("D... in main of project/module:  notifator/telegram ")
    print("D... notifator version :", __version__ )
    #Fire(  )
    Fire({"send":bot_send,
 #         "get_token":get_token,
          "load":load_config,
    }
    )



#!/usr/bin/python3

from fire import Fire
from gtts import gTTS
import datetime as dt
from pydub import AudioSegment
import glob
import os

ONAME = "tmp.mp3"


def gspeak3( s ):
    """
    ... should also  put mp3  into cache in future
    """
    print(f"i... {s}  ... {ONAME}")
    #tts = gTTS('14:31', lang='cs')
    tts = gTTS( s, lang='cs')
    tts.save( ONAME )
    # Load the saved file with pydub
    sound = AudioSegment.from_file( ONAME )
    print("# Increase the volume")
    louder_sound = sound + 10  # Increase volume by 10 dB
    # Save the result
    louder_sound.export( ONAME, format='mp3')
    return ONAME



def get_mp3(h,m,dirname="~/sound_cache/"):
    """
    preferably get from cache
    """
    DD =  os.path.expanduser(dirname)
    li=sorted( glob.glob( DD+"/*mp3" ) )
    nam = f"{h:02d}_{m:02d}.mp3"
    nam = f"{DD}/{nam}"
    nam = nam.replace("//","/")
    print("i...  searching",nam)
    if nam in li:
        print("i... FOUND")
        return nam
    else:
        #print(li)
        return None


def hodiny( h=None,m=None):
    """

    """
    print("D... really hodiny")
    if h is None or m is None:
        i = int( dt.datetime.now().strftime("%H") )
        j = int( dt.datetime.now().strftime("%M") )
    else:
        i= int(h)
        j= int(m)

    FNAME = get_mp3(i,j)
    print("D... really hodiny FNAME:", FNAME)

    if FNAME is not None:
        print(f"i... file exists: {FNAME}  . saving {ONAME}")
        sound = AudioSegment.from_file( FNAME )
        sound.export( ONAME, format='mp3')
        print("D... returning (old) filename : ", ONAME)
        return ONAME

    print(f"{i} : {j}")

    H1="hodina"
    H2="hodiny"
    H3="hodin"
    M1="minuta"
    M2="minuty"
    M3="minut"

    #for i in range(24):
    ho=""
    if i == 0:  ho = ho + f"{i} {H3}"
    if i == 1:  ho = ho + f"{i} {H1}"
    if i == 2:  ho = ho + f"{i} {H2}"
    if i == 3:  ho = ho + f"{i} {H2}"
    if i == 4:  ho = ho + f"{i} {H2}"
    if i > 4:   ho = ho + f"{i} {H3}"

    #for i in range(60):
    if j == 0: ho = ho +  f" {j} {M3}"
    if j == 1: ho = ho +  f" {j} {M1}"
    if j == 2: ho = ho +  f" {j} {M2}"
    if j == 3: ho = ho +  f" {j} {M2}"
    if j == 4: ho = ho +  f" {j} {M2}"
    if j > 4:  ho = ho +  f" {j} {M3}"

    mp3file = gspeak3( ho ) # just save mp3
    print("D... returning (new) filename : ", mp3file)
    return mp3file

#       mv masnun.wav  ${i}_hod.wav
#       lame  ${i}_hod.wav
#       sleep 10

if __name__=="__main__":
    Fire(main)
